# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Added

### Changed

### Removed

## 0.3.1

### Fixed

Added ``skip`` to ``__all__``

## 0.3.0

### Added

* Added support for ``pytest.mark.skip`` tests.

### Changed

### Removed

## 0.2.1

### Changed

* Fixed issue with single argument in parametrized marker without stacking

## 0.2.0

### Added

* Added support for stacked parametrized decorators

## 0.1.1

## 0.1.0

* Initial version
